==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/HierarchicalRingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { HierarchicalRingSeriesDescription } from "./HierarchicalRingSeriesDescription";
/**
 * @hidden
 */
var HierarchicalRingSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HierarchicalRingSeriesDescriptionMetadata, _super);
    function HierarchicalRingSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HierarchicalRingSeriesDescriptionMetadata.b = function (a) {
        if (HierarchicalRingSeriesDescriptionMetadata.a == null) {
            HierarchicalRingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HierarchicalRingSeriesDescriptionMetadata.c(HierarchicalRingSeriesDescriptionMetadata.a);
        }
        if (a.g(HierarchicalRingSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(HierarchicalRingSeriesDescriptionMetadata.a);
    };
    HierarchicalRingSeriesDescriptionMetadata.c = function (a) {
        RingSeriesBaseDescriptionMetadata.c(a);
        a.item("ChildrenMemberPath", "String");
    };
    HierarchicalRingSeriesDescriptionMetadata.d = function (a) {
        HierarchicalRingSeriesDescriptionMetadata.b(a);
        a.u("HierarchicalRingSeries", function () { return new HierarchicalRingSeriesDescription(); });
        a.t("HierarchicalRingSeries", HierarchicalRingSeriesDescriptionMetadata.a);
    };
    HierarchicalRingSeriesDescriptionMetadata.$t = markType(HierarchicalRingSeriesDescriptionMetadata, 'HierarchicalRingSeriesDescriptionMetadata');
    HierarchicalRingSeriesDescriptionMetadata.a = null;
    return HierarchicalRingSeriesDescriptionMetadata;
}(Base));
export { HierarchicalRingSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/HierarchicalRingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { HierarchicalRingSeriesDescription } from "./HierarchicalRingSeriesDescription";
/**
 * @hidden
 */
var HierarchicalRingSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HierarchicalRingSeriesDescriptionMetadata, _super);
    function HierarchicalRingSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HierarchicalRingSeriesDescriptionMetadata.b = function (a) {
        if (HierarchicalRingSeriesDescriptionMetadata.a == null) {
            HierarchicalRingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HierarchicalRingSeriesDescriptionMetadata.c(HierarchicalRingSeriesDescriptionMetadata.a);
        }
        if (a.j(HierarchicalRingSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(HierarchicalRingSeriesDescriptionMetadata.a);
    };
    HierarchicalRingSeriesDescriptionMetadata.c = function (a) {
        RingSeriesBaseDescriptionMetadata.c(a);
        a.item("ChildrenMemberPath", "String");
    };
    HierarchicalRingSeriesDescriptionMetadata.d = function (a) {
        HierarchicalRingSeriesDescriptionMetadata.b(a);
        a.aa("HierarchicalRingSeries", function () { return new HierarchicalRingSeriesDescription(); });
        a.z("HierarchicalRingSeries", HierarchicalRingSeriesDescriptionMetadata.a);
    };
    HierarchicalRingSeriesDescriptionMetadata.$t = markType(HierarchicalRingSeriesDescriptionMetadata, 'HierarchicalRingSeriesDescriptionMetadata');
    HierarchicalRingSeriesDescriptionMetadata.a = null;
    return HierarchicalRingSeriesDescriptionMetadata;
}(Base));
export { HierarchicalRingSeriesDescriptionMetadata };
